### [English](#activereportsjs) | [日本語](#activereportsjs-jp) | [中文](#activereportsjs-cn)
____

# ActiveReportsJS



* ActiveReportsJS (ARJS) is JavaScript version of ActiveReports that can work on any modern browser. It doesn't have server-dependency. 

* Supported report types are "Page" and "RDL".



## Installation



Install all ActiveReportsJS javascript components using `npm install @grapecity/activereports`



## Documentation



For more information on how to use ActiveReportsJS and available tools, refer to the [Documentation](https://www.grapecity.com/activereportsjs/docs/) or [API reference](https://www.grapecity.com/activereportsjs/api/) for guidance.



## Samples



View ActiveReportsJS demos [here](https://www.grapecity.com/activereportsjs/demos/).





## Tutorial - Creating your first **ActiveReportsJS Viewer** application 



### Steps

1. In `index.html` head section add reference to `ar-js-core.js` and `ar-js-viewer.js` from `dist` folder and `ar-js-viewer.css` from `styles` folder:
```html
    <link rel="stylesheet" type="text/css" href="/styles/ar-js-viewer.css">

    <script src="/dist/ar-js-core.js"></script>
    <script src="/dist/ar-js-viewer.js"></script>
```

2. if IE11 support is needed, in `index.html` in head section (above `ar-js-core.js` and `ar-js-viewer.js`) add reference to `ie-polyfills.js` from `dist` folder:
```html
    <script src="/dist/ie-polyfills.js"></script>
```

3. If exports support is needed, in `index.html` head section add reference(s) to `ar-js-pdf.js`, `ar-js-html.js` or `ar-js-xlsx.js` from `dist` folder:
```html
    <script src="/dist/ar-js-pdf.js"></script>
    <script src="/dist/ar-js-html.js"></script>
    <script src="/dist/ar-js-xlsx.js"></script>
```

4. In `index.html` body section add div with id to host *ActiveReportsJS Viewer*. Note, that it requires container height to be defined:
```html
    <div id="root" style="height: 100vh"></div>
```

5. In `index.html` add script to load viewer and subscribe it to body `onload` event:
```html
<body onload="loadViewer()">
    <script>
        function loadViewer() {
            var viewer = new ActiveReports.Viewer('#root');
            viewer.open({
              "Name": "Report",
              "Type": "report",
              "Body": {
                "Name": "Body",
                "Type": "section",
                "ReportItems": [
                   { Type: "textbox", Name: "textbox1", Value: "Hello from ActiveReports", Top: "3in", Left: "3in", Height: "1in" }
                 ]
               }
            });
        }
     </script>

    <div id="root" style="height: 100vh"></div>
</body>
```


## Designer



To create and modify reports, you will need **ActiveReportsJS Designer**. Download the ActiveReportsJS designer [here](https://www.grapecity.com/activereportsjs/) for  MacOS, Win, or Linux, to get started.

# ActiveReportsJS JP
[ActiveReportsJS](https://www.grapecity.co.jp/developer/activereportsjs)は、モダンなWebアプリケーションに帳票出力機能を組み込めるJavaScriptコントロールです。帳票の外観デザインの設定からデータ接続、印刷、PDFやExcelへの出力まで、Web帳票開発に必要な機能が揃っています。

## サンプル
[ActiveReportsJSチュートリアルデモ](https://demo.grapecity.com/activereportsjs/demos/)では、ActiveReportsJSを使用したアプリケーションの作成方法や、各コントロールの基本機能、実用的なアプリケーションの例などを紹介しています。

また、[トライアル版](https://www.grapecity.co.jp/developer/download#javascript)をダウンロードして、実際の機能や動作をご確認いただけます。

## インストール方法
```sh
npm install @grapecity/activereports
```
日本語版での動作保証は日本語版サイトで公開しているバージョンのみとなります。

## ドキュメント
製品の各種ドキュメントは、下記をご参照ください。
- [製品ヘルプ](https://demo.grapecity.com/activereportsjs/docs/)
- [チュートリアルデモ](https://demo.grapecity.com/activereportsjs/demos/)

## 製品情報
製品の詳細や価格、ライセンスについては、下記をご参照ください。
[https://www.grapecity.co.jp/developer/activereportsjs](https://www.grapecity.co.jp/developer/activereportsjs)


# ActiveReportsJS CN


* ActiveReportsJS 是一个轻量级的报表解决方案，为您提供简单易用的丰富的 API ，创建复杂报表，轻松集成到您的项目重 为了满足常用的报表布局需求，不需要依赖于服务端。

* ActiveReportsJS支持以下报表类型："页面" 和"RDL 报表"。




## 安装

使用命令 `npm install @grapecity/activereports` 安装 ActiveReportsJS



## 产品资料


更多产品资料请点击 [帮助文档](https://demo.grapecity.com.cn/activereportsjs/docs/GettingStarted/Introduction) 或 [API 文档](https://demo.grapecity.com.cn/activereportsjs/api/) 。



## 示例


 [ActiveReportsJS 示例](https://demo.grapecity.com.cn/activereportsjs/demos/Reports/InvoiceList/purejs).





## 入门指南 - 创建第一个 **ActiveReportsJS Viewer** 应用 



### 操作步骤

1. 在 `index.html` head 标签内添加 `dist`文件夹中的 js 文件的引用， `ar-js-core.js` 、 `ar-js-viewer.js`   及`styles` 文件夹中的css文件 `ar-js-viewer.css`  :
```html
    <link rel="stylesheet" type="text/css" href="/styles/ar-js-viewer.css">

    <script src="/dist/ar-js-core.js"></script>
    <script src="/dist/ar-js-viewer.js"></script>
```

2. 如果需要支持 IE11 , 也需要在 `index.html` head标签内添加`ie-polyfills.js`文件 (具体位置要在 `ar-js-core.js` 和 `ar-js-viewer.js`文件前面引用) 
```html
    <script src="/dist/ie-polyfills.js"></script>
```

3. 如果需要支持导出按钮， 需要添加  `ar-js-pdf.js`, `ar-js-html.js` 及 `ar-js-xlsx.js`  `dist` 文件夹的引用:
```html
    <script src="/dist/ar-js-pdf.js"></script>
    <script src="/dist/ar-js-html.js"></script>
    <script src="/dist/ar-js-xlsx.js"></script>
```

4. 在 `index.html` body 标签内声明 div 用于展示 *ActiveReportsJS Viewer*。 注意, 必须要定义height属性:
```html
    <div id="root" style="height: 100vh"></div>
```

5. 在 `index.html`  body `onload` 事件中添加以下脚本:
```html
<body onload="loadViewer()">
    <script>
        function loadViewer() {
            var viewer = new ActiveReports.Viewer('#root');
            viewer.open({
              "Name": "Report",
              "Type": "report",
              "Body": {
                "Name": "Body",
                "Type": "section",
                "ReportItems": [
                   { Type: "textbox", Name: "textbox1", Value: "Hello from ActiveReports", Top: "3in", Left: "3in", Height: "1in" }
                 ]
               }
            });
        }
     </script>

    <div id="root" style="height: 100vh"></div>
</body>
```


## 设计器



我们提供了 Windows,Mac,Linux 三个版本的设计器报表设计器 **ActiveReportsJS Designer**。下载[设计器](https://downloads.grapecity.com.cn/ActiveReportsJS/ActiveReportsJS_Beta.zip) 